# Generated by Django 3.2.16 on 2022-11-24 12:05

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Token',
            fields=[
                ('key', models.CharField(max_length=40, primary_key=True, serialize=False, verbose_name='Key')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('last_use', models.DateTimeField(auto_now=True, verbose_name='Last use')),
                ('verification_code', models.CharField(blank=True, max_length=5, null=True)),
                ('expiry_date', models.DateTimeField(blank=True, null=True)),
                ('authenticated', models.BooleanField(default=False)),
            ],
            options={
                'verbose_name': 'Token',
                'verbose_name_plural': 'Tokens',
                'db_table': 'AUTHENTICATION_TOKEN',
                'managed': False,
            },
        ),
    ]
